summaryrefslogtreecommitdiffstats
path: root/certmanager/lib/ui/cryptoconfigmodule.h
diff options
context:
space:
mode:
Diffstat (limited to 'certmanager/lib/ui/cryptoconfigmodule.h')
-rw-r--r--certmanager/lib/ui/cryptoconfigmodule.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/certmanager/lib/ui/cryptoconfigmodule.h b/certmanager/lib/ui/cryptoconfigmodule.h
index 18581459..70c4a269 100644
--- a/certmanager/lib/ui/cryptoconfigmodule.h
+++ b/certmanager/lib/ui/cryptoconfigmodule.h
@@ -34,7 +34,7 @@
#include <kjanuswidget.h>
-#include <qvaluelist.h>
+#include <tqvaluelist.h>
namespace Kleo {
@@ -43,12 +43,12 @@ namespace Kleo {
/**
* Crypto Config Module widget, dynamically generated from CryptoConfig
* It's a simple QWidget so that it can be embedded into a dialog or into a KCModule.
*/
class CryptoConfigModule : public KJanusWidget {
Q_OBJECT
public:
- CryptoConfigModule( Kleo::CryptoConfig* config, QWidget * parent=0, const char * name=0 );
+ CryptoConfigModule( Kleo::CryptoConfig* config, TQWidget * parent=0, const char * name=0 );
void save();
void reset(); // i.e. reload current settings, discarding user input
@@ -60,7 +60,7 @@ namespace Kleo {
private:
Kleo::CryptoConfig* mConfig;
- QValueList<CryptoConfigComponentGUI *> mComponentGUIs;
+ TQValueList<CryptoConfigComponentGUI *> mComponentGUIs;
};
}
@@ -43,12 +43,12 @@ namespace Kleo {
/**
* Crypto Config Module widget, dynamically generated from CryptoConfig
- * It's a simple QWidget so that it can be embedded into a dialog or into a KCModule.
+ * It's a simple TQWidget so that it can be embedded into a dialog or into a KCModule.
*/
class CryptoConfigModule : public KJanusWidget {